import sbt._

class CCFirstLab(info: ProjectInfo) extends DefaultProject(info) with FileTasks {
  val scalatest = "org.scalatest" % "scalatest" % "1.2"

  override def outputDirectoryName          = "bin"
  override def dependencyPath               = "lib"
  override def mainScalaSourcePath          = "src"
  override def testScalaSourcePath          = "test"
  override def shouldCheckOutputDirectories = false
  override def compileOptions               = super.compileOptions ++ Seq(Unchecked)

  val scriptPath : Path = "." / "whilelang"

  lazy val script = genScript
  def genScript = fileTask(scriptPath :: Nil)({
    log.info("Generating runner (sh) script")
    try {
      val nl = System.getProperty("line.separator")
      val f = scriptPath.asFile
      val fw = new java.io.FileWriter(f)
      fw.write("#!/bin/sh" + nl)
      fw.write("CLASSPATH=")
      fw.write(dependencyPath.absolutePath + "/whilelang-parser.jar" + ":")
      fw.write(mainCompilePath.absolutePath + nl)
      fw.write("scala -cp ${CLASSPATH} whilelang.Main $@" + nl)
      fw.close
      f.setExecutable(true)
      None
    } catch {
      case e => Some("There was an error while generating the script file: " + e.getLocalizedMessage)
    }
  }) dependsOn(compile) describedAs("Produce the runner (sh) script.")
}
